Design overview
===============

.. image:: design.svg
   :align: center
   :width: 600px

*mbrs* consists of several modules:

- Metrics calculate utility scores

  - :doc:`list_metrics`
  - :doc:`custom_metric`

- Decoders call component methods and return the outputs

  - :doc:`list_decoders`
  - :doc:`custom_decoder`

- Selector decides the final output list

  - :doc:`list_selectors`
